@@ -23,6 +23,7 @@ from calculate.lib.datavars import (Variable,VariableError,ReadonlyVariable,
 from calculate.lib.cl_template import iniParser
 from calculate.lib.utils.files import readLinesFile,isMount,readFile, find
 from calculate.lib.utils.common import getValueFromCmdLine,cmpVersion
+from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.variables.user import VariableUrLogin
 from calculate.lib.convertenv import convertEnv
 from calculate.lib.utils.ip import isOpenPort
@@ -666,3 +667,13 @@ class VariableClCifsVer(ReadonlyVariable):
     """
     def get(self):
         return readFile("/sys/module/cifs/version")
+
+class VariableClRsyncVer(ReadonlyVariable):
+    """
+    Версия rsync
+    """
+    def get(self):
+        data = isPkgInstalled('net-misc/rsync')
+        if data:
+            return data[0]['PVR']
+        return ""
